@@ -1,6 +1,6 @@
 package Ubic::Daemon::OS::Linux;
 BEGIN {
-  $Ubic::Daemon::OS::Linux::VERSION = '1.32_04';
+  $Ubic::Daemon::OS::Linux::VERSION = '1.33_01';
 }
 
 use strict;
@@ -41,7 +41,9 @@ sub pid2cmd {
     my $daemon_cmd = <$daemon_cmd_fh>;
     unless ($daemon_cmd) {
         # strange, open succeeded but file is empty
-        die "Can't read daemon cmdline";
+        # this can happen, though, for example if pid belongs to the kernel thread
+        warn "Can't read daemon cmdline";
+        return 'unknown';
     }
     $daemon_cmd =~ s/\x{00}$//;
     $daemon_cmd =~ s/\x{00}/ /g;
@@ -76,7 +78,7 @@ Ubic::Daemon::OS::Linux - linux-specific daemonize helpers
 
 =head1 VERSION
 
-version 1.32_04
+version 1.33_01
 
 =head1 DESCRIPTION
 
